parse_quote_tick

Function parse_quote_tick 

pub fn parse_quote_tick(
    instrument_id: InstrumentId,
    bid_price: Option<f64>,
    ask_price: Option<f64>,
    bid_size: Option<f64>,
    ask_size: Option<f64>,
    price_precision: u8,
    size_precision: u8,
    ts_event: UnixNanos,
    ts_init: UnixNanos,
) -> Result<QuoteTick>
Parse IB tick price and size data into a QuoteTick.

This builds a quote from individual tick updates. You typically need to accumulate bid/ask prices and sizes from multiple tick updates before creating a QuoteTick.

Errors

Returns an error if price or size conversion fails.